==> jc-1.4.0.tar.gz: javax/naming/ldap/LdapReferralException.h <==
// public abstract class javax.naming.ldap.LdapReferralException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class fadee18b7599c8d5 javax_naming_NamingException
// @dep_class 7961821e227a0a49 javax_naming_ReferralException
// @dep_class b4ec5fe960b655b8 javax_naming_ldap_LdapReferralException

// header file dependencies
// @dep_header javax_naming_ReferralException

#include "javax/naming/ReferralException.h"

#ifndef _JC_javax_naming_ldap_LdapReferralException_H_
#define _JC_javax_naming_ldap_LdapReferralException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;
struct _jc_javax_naming_Context$object;

// Typedefs
typedef struct _jc_javax_naming_ldap_LdapReferralException$sub_refs	_jc_javax_naming_ldap_LdapReferralException$sub_refs;
typedef struct _jc_javax_naming_ldap_LdapReferralException$sub_nonrefs	_jc_javax_naming_ldap_LdapReferralException$sub_nonrefs;
typedef struct _jc_javax_naming_ldap_LdapReferralException$refs	_jc_javax_naming_ldap_LdapReferralException$refs;
typedef struct _jc_javax_naming_ldap_LdapReferralException$nonrefs	_jc_javax_naming_ldap_LdapReferralException$nonrefs;
typedef struct _jc_javax_naming_ldap_LdapReferralException$object	_jc_javax_naming_ldap_LdapReferralException$object;

typedef const struct _jc_javax_naming_ldap_LdapReferralException$vmethods	_jc_javax_naming_ldap_LdapReferralException$vmethods;
typedef const struct _jc_javax_naming_ldap_LdapReferralException$vtable	_jc_javax_naming_ldap_LdapReferralException$vtable;
typedef const struct _jc_javax_naming_ldap_LdapReferralException$vtype	_jc_javax_naming_ldap_LdapReferralException$vtype;

// Constructors
extern void _jc_javax_naming_ldap_LdapReferralException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_naming_ldap_LdapReferralException$object *);
extern void _jc_javax_naming_ldap_LdapReferralException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_naming_ldap_LdapReferralException$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_object *_jc_javax_naming_ldap_LdapReferralException$method$getReferralContext$ffdbd6221eb269af(_jc_env *, struct _jc_javax_naming_ldap_LdapReferralException$object *);
extern struct _jc_object *_jc_javax_naming_ldap_LdapReferralException$method$getReferralContext$f81f12c3eb996fff(_jc_env *, struct _jc_javax_naming_ldap_LdapReferralException$object *, struct _jc_java_util_Hashtable$object *);
extern struct _jc_object *_jc_javax_naming_ldap_LdapReferralException$method$getReferralContext$58828d63988859d9(_jc_env *, struct _jc_javax_naming_ldap_LdapReferralException$object *, struct _jc_java_util_Hashtable$object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_javax_naming_ldap_LdapReferralException$method_info$getReferralContext$ffdbd6221eb269af;
extern _jc_method _jc_javax_naming_ldap_LdapReferralException$method_info$getReferralContext$f81f12c3eb996fff;
extern _jc_method _jc_javax_naming_ldap_LdapReferralException$method_info$getReferralContext$58828d63988859d9;

// Virtual methods structure
struct _jc_javax_naming_ldap_LdapReferralException$vmethods {
	struct _jc_object	*(*getReferralContext$ffdbd6221eb269af)(_jc_env *, struct _jc_javax_naming_ldap_LdapReferralException$object *);
	struct _jc_object	*(*getReferralContext$f81f12c3eb996fff)(_jc_env *, struct _jc_javax_naming_ldap_LdapReferralException$object *, struct _jc_java_util_Hashtable$object *);
	struct _jc_object	*(*getReferralContext$58828d63988859d9)(_jc_env *, struct _jc_javax_naming_ldap_LdapReferralException$object *, struct _jc_java_util_Hashtable$object *, struct _jc_object_array *);
};

// Vtable
struct _jc_javax_naming_ldap_LdapReferralException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_naming_NamingException$vmethods	javax_naming_NamingException;
	_jc_javax_naming_ReferralException$vmethods	javax_naming_ReferralException;
	_jc_javax_naming_ldap_LdapReferralException$vmethods	javax_naming_ldap_LdapReferralException;
};

// Vtype
struct _jc_javax_naming_ldap_LdapReferralException$vtype {
	_jc_type			type;
	_jc_javax_naming_ldap_LdapReferralException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_ldap_LdapReferralException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_naming_ldap_LdapReferralException$refs {
    _jc_javax_naming_ldap_LdapReferralException$sub_refs	javax_naming_ldap_LdapReferralException;
    _jc_javax_naming_ReferralException$sub_refs	javax_naming_ReferralException;
    _jc_javax_naming_NamingException$sub_refs	javax_naming_NamingException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_ldap_LdapReferralException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_ldap_LdapReferralException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_naming_NamingException$sub_nonrefs	javax_naming_NamingException;
    _jc_javax_naming_ReferralException$sub_nonrefs	javax_naming_ReferralException;
    _jc_javax_naming_ldap_LdapReferralException$sub_nonrefs	javax_naming_ldap_LdapReferralException;
};

// Object instance structure
struct _jc_javax_naming_ldap_LdapReferralException$object {
	_jc_javax_naming_ldap_LdapReferralException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_ldap_LdapReferralException$vtype	*vtype;
	_jc_javax_naming_ldap_LdapReferralException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_ldap_LdapReferralException$vtype _jc_javax_naming_ldap_LdapReferralException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_ldap_LdapReferralException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_ldap_LdapReferralException$class_object;

#endif	/* _JC_javax_naming_ldap_LdapReferralException_H_ */

==> jc-1.4.6.tar.gz: javax/naming/ldap/LdapReferralException.h <==
// public abstract class javax.naming.ldap.LdapReferralException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class fadee18b7599c8d5 javax_naming_NamingException
// @dep_class 7961821e227a0a49 javax_naming_ReferralException
// @dep_class b4ec5fe960b655b8 javax_naming_ldap_LdapReferralException

// header file dependencies
// @dep_header javax_naming_ReferralException

#include "javax/naming/ReferralException.h"

#ifndef _JC_javax_naming_ldap_LdapReferralException_H_
#define _JC_javax_naming_ldap_LdapReferralException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;
struct _jc_javax_naming_Context$object;

// Typedefs
typedef struct _jc_javax_naming_ldap_LdapReferralException$sub_refs	_jc_javax_naming_ldap_LdapReferralException$sub_refs;
typedef struct _jc_javax_naming_ldap_LdapReferralException$sub_nonrefs	_jc_javax_naming_ldap_LdapReferralException$sub_nonrefs;
typedef struct _jc_javax_naming_ldap_LdapReferralException$refs	_jc_javax_naming_ldap_LdapReferralException$refs;
typedef struct _jc_javax_naming_ldap_LdapReferralException$nonrefs	_jc_javax_naming_ldap_LdapReferralException$nonrefs;
typedef struct _jc_javax_naming_ldap_LdapReferralException$object	_jc_javax_naming_ldap_LdapReferralException$object;

typedef const struct _jc_javax_naming_ldap_LdapReferralException$vmethods	_jc_javax_naming_ldap_LdapReferralException$vmethods;
typedef const struct _jc_javax_naming_ldap_LdapReferralException$vtable	_jc_javax_naming_ldap_LdapReferralException$vtable;
typedef const struct _jc_javax_naming_ldap_LdapReferralException$vtype	_jc_javax_naming_ldap_LdapReferralException$vtype;

// Constructors
extern void _jc_javax_naming_ldap_LdapReferralException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_naming_ldap_LdapReferralException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_naming_ldap_LdapReferralException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_naming_ldap_LdapReferralException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_naming_ldap_LdapReferralException$method$getReferralContext$ffdbd6221eb269af(_jc_env *, struct _jc_javax_naming_ldap_LdapReferralException$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_naming_ldap_LdapReferralException$method$getReferralContext$f81f12c3eb996fff(_jc_env *, struct _jc_javax_naming_ldap_LdapReferralException$object *, struct _jc_java_util_Hashtable$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_naming_ldap_LdapReferralException$method$getReferralContext$58828d63988859d9(_jc_env *, struct _jc_javax_naming_ldap_LdapReferralException$object *, struct _jc_java_util_Hashtable$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_naming_ldap_LdapReferralException$method_info$getReferralContext$ffdbd6221eb269af;
extern _jc_method _jc_javax_naming_ldap_LdapReferralException$method_info$getReferralContext$f81f12c3eb996fff;
extern _jc_method _jc_javax_naming_ldap_LdapReferralException$method_info$getReferralContext$58828d63988859d9;

// Virtual methods structure
struct _jc_javax_naming_ldap_LdapReferralException$vmethods {
	struct _jc_object	*(*getReferralContext$ffdbd6221eb269af)(_jc_env *, struct _jc_javax_naming_ldap_LdapReferralException$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getReferralContext$f81f12c3eb996fff)(_jc_env *, struct _jc_javax_naming_ldap_LdapReferralException$object *, struct _jc_java_util_Hashtable$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getReferralContext$58828d63988859d9)(_jc_env *, struct _jc_javax_naming_ldap_LdapReferralException$object *, struct _jc_java_util_Hashtable$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_naming_ldap_LdapReferralException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_naming_NamingException$vmethods	javax_naming_NamingException;
	_jc_javax_naming_ReferralException$vmethods	javax_naming_ReferralException;
	_jc_javax_naming_ldap_LdapReferralException$vmethods	javax_naming_ldap_LdapReferralException;
};

// Vtype
struct _jc_javax_naming_ldap_LdapReferralException$vtype {
	_jc_type			type;
	_jc_javax_naming_ldap_LdapReferralException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_ldap_LdapReferralException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_naming_ldap_LdapReferralException$refs {
    _jc_javax_naming_ldap_LdapReferralException$sub_refs	javax_naming_ldap_LdapReferralException;
    _jc_javax_naming_ReferralException$sub_refs	javax_naming_ReferralException;
    _jc_javax_naming_NamingException$sub_refs	javax_naming_NamingException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_ldap_LdapReferralException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_ldap_LdapReferralException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_naming_NamingException$sub_nonrefs	javax_naming_NamingException;
    _jc_javax_naming_ReferralException$sub_nonrefs	javax_naming_ReferralException;
    _jc_javax_naming_ldap_LdapReferralException$sub_nonrefs	javax_naming_ldap_LdapReferralException;
};

// Object instance structure
struct _jc_javax_naming_ldap_LdapReferralException$object {
	_jc_javax_naming_ldap_LdapReferralException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_ldap_LdapReferralException$vtype	*vtype;
	_jc_javax_naming_ldap_LdapReferralException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_ldap_LdapReferralException$vtype _jc_javax_naming_ldap_LdapReferralException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_ldap_LdapReferralException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_ldap_LdapReferralException$class_object;

#endif	/* _JC_javax_naming_ldap_LdapReferralException_H_ */
